@@ -247,6 +247,24 @@ bool StatusHildon::HandleMessage(DBusConnection *connection, DBusMessage *msg)
 
     dbus_message_iter_next(&iter);
 
+    network.encryption=0;
+
+    if (uintValue & (1<<4)) {
+      network.encryption|=cryptNone;
+    }
+    if (uintValue & (1<<5)) {
+      network.encryption|=cryptWEP;
+    }
+    if (uintValue & (1<<6)) {
+      network.encryption|=cryptWPA_PSK;
+    }
+    if (uintValue & (1<<7)) {
+      network.encryption|=cryptWPA_EAP;
+    }
+    if (uintValue & (1<<8)) {
+      network.encryption|=cryptWPA2;
+    }
+
     if (!network.essid.empty()) {
       networks.push_back(network);
     }
