@@ -283,7 +283,7 @@ private:
         Lum::FuelGauge                  *gauge;
         Lum::Model::DoubleRef           data;
 
-        gauge=dynamic_cast<Lum::FuelGauge*>(entry->GetObject(3));
+        gauge=dynamic_cast<Lum::FuelGauge*>(entry->GetObject(4));
         data=dynamic_cast<Lum::Model::Double*>(gauge->GetModel());
 
         data->Set(iter->quality);
@@ -292,6 +292,7 @@ private:
         Lum::FuelGauge                  *gauge;
         Lum::Model::DoubleRef           data;
         Lum::Model::ListTable::StdEntry *entry;
+        std::wstring                    encryption;
 
         gauge=new Lum::FuelGauge();
         gauge->SetFlex(true,false);
@@ -304,7 +305,25 @@ private:
         entry=new Lum::Model::ListTable::StdEntry(tableModel);
         entry->SetString(1,iter->essid);
         entry->SetString(2,Lum::Base::NumberToWString(iter->channel));
-        entry->SetObject(3,gauge);
+
+        if (iter->encryption & Status::cryptNone) {
+          encryption.append(L"N");
+        }
+        if (iter->encryption & Status::cryptWEP) {
+          encryption.append(L"W");
+        }
+        if (iter->encryption & Status::cryptWPA_PSK) {
+          encryption.append(L"P");
+        }
+        if (iter->encryption & Status::cryptWPA_EAP) {
+          encryption.append(L"E");
+        }
+        if (iter->encryption & Status::cryptWPA2) {
+          encryption.append(L"2");
+        }
+
+        entry->SetString(3,encryption);
+        entry->SetObject(4,gauge);
 
         tableModel->Append(entry);
       }
@@ -442,6 +461,7 @@ public:
       headerModel=new Lum::Model::HeaderImpl();
       headerModel->AddColumn(L"ESSID",Lum::Base::Size::stdCharWidth,15,true);
       headerModel->AddColumn(L"C",Lum::Base::Size::stdCharWidth,2);
+      headerModel->AddColumn(L"Encrypt",Lum::Base::Size::stdCharWidth,7);
       headerModel->AddColumn(L"Quality",Lum::Base::Size::stdCharWidth,10);
 
       table=new Lum::Table();
